# Raw Art Decor to Simple JSON

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)

## Description

This Python module provides a convenient way to reformat raw art decor JSON into a simplified JSON format. It aims to make the process of working with art decor data easier and more efficient.

## Features

- Converts raw art decor JSON into a simplified JSON format
- Handles various types of art decor data structures
- Provides customizable options for formatting

## Installation

To install the module, simply run the following command:

```shell




TODO
- get import to work in test 
    - how do i import a package that is in a subfolder
- Am i adding logging into this? 
